

# Welcome to the ribbity test site!

This page is made from a generic jinja2 template that comes with ribbity.

You can see [the template here](https://github.com/ctb/ribbity/blob/main/ribbity/templates/index.md).

Make a copy, put it in `./site-templates`, and edit it for your own project!

## Start here!




[Example: test TOML config](3-test-toml-config.md)














---

## [All examples](examples.md)

---

## [All categories](labels.md)
